#!/usr/bin/env python
# (c) Copyright 2010 Cloudera, Inc. All rights reserved.

"""
Common utils for beeswax.
"""

import re

from django import forms
from beeswax import db_utils


HIVE_IDENTIFER_REGEX = re.compile("[a-zA-Z0-9]\w*")

DL_FORMATS = [ 'csv', 'xls' ]

SELECTION_SOURCE = [ '', 'table', 'constant', ]

AGGREGATIONS = [ '', 'COUNT', 'SUM', 'AVG', 'MIN', 'MAX' ]

JOIN_TYPES = [ '', 'LEFT OUTER JOIN', 'RIGHT OUTER JOIN', 'FULL OUTER JOIN', 'JOIN' ]

SORT_OPTIONS = [ '', 'ascending', 'descending' ]

RELATION_OPS_UNARY = [ 'IS NULL', 'IS NOT NULL', 'NOT' ]

RELATION_OPS = [ '=', '<>', '<', '<=', '>', '>=' ] + RELATION_OPS_UNARY


def to_choices(x):
  """
  Maps [a, b, c] to [(a,a), (b,b), (c,c)].
  Useful for making ChoiceField's.
  """
  return [ (y, y) for y in x ]


class HiveIdentifierField(forms.RegexField):
  """
  Corresponds to 'Identifier' in Hive.g (Hive's grammar)
  """
  def __init__(self, *args, **kwargs):
    kwargs['regex'] = HIVE_IDENTIFER_REGEX
    super(HiveIdentifierField, self).__init__(*args, **kwargs)


class HiveTableChoiceField(forms.ChoiceField):
  """To choose from a defined table"""
  def __init__(self, *args, **kwargs):
    table_names = db_utils.meta_client().get_tables("default", ".*")
    kwargs['choices'] = to_choices([''] + table_names)
    forms.ChoiceField.__init__(self, *args, **kwargs)


