#!/usr/bin/env python
# (c) Copyright 2010 Cloudera, Inc. All rights reserved.
"""
Starts the beeswax server.
"""

from django.core.management.base import NoArgsCommand
import beeswax.conf
import beeswax.hive_site
import hadoop.conf
import os
import logging

LOG = logging.getLogger(__name__)

class Command(NoArgsCommand):
  """ Starts beeswax daemon.  """
  def handle_noargs(self, **options):
    env = os.environ.copy()
    env['HADOOP_HOME'] = hadoop.conf.HADOOP_HOME.get()
    if hadoop.conf.HADOOP_CONF_DIR.get():
      env['HADOOP_CONF_DIR'] = hadoop.conf.HADOOP_CONF_DIR.get()
    if beeswax.conf.BEESWAX_HIVE_CONF_DIR.get():
      env['HIVE_CONF_DIR'] = beeswax.conf.BEESWAX_HIVE_CONF_DIR.get()
    bin = beeswax.conf.BEESWAX_SERVER_BIN.get()
    args = [
      os.path.basename(bin),
      '--beeswax',
      str(beeswax.conf.BEESWAX_SERVER_PORT.get()),
    ]

    # Start metastore as well?
    is_local, host, port = beeswax.hive_site.get_metastore()
    if not is_local:
      LOG.info("Beeswax configured to use external metastore at %s:%s" % (host, port))
    else:
      args += [ '--metastore', str(beeswax.conf.BEESWAX_META_SERVER_PORT.get()) ]

    LOG.info("Executing %r (%r) (%r)" % (bin, args, env))
    # Use exec, so that this takes only one process.
    os.execve(bin, args, env)
